@@ -32,19 +32,23 @@ class SQLMapping(object):
         for m_SQL_MappingFile in list(m_SQL_Mappings):
             m_SQL_MappingBaseName = None
             m_SQL_MappingFullName = None
-            if os.path.exists(m_SQL_MappingFile):
+
+            # 如果以.map结尾，去掉最后的.map
+            if m_SQL_MappingFile.endswith(".map"):
+                m_SQL_MappingFile = m_SQL_MappingFile[0: len(m_SQL_MappingFile)-4]
+
+            if os.path.isfile(m_SQL_MappingFile):
                 # 用户提供的是全路径名
                 m_SQL_MappingBaseName = os.path.basename(m_SQL_MappingFile)  # 不包含路径的文件名
-                m_SQL_MappingFullName = m_SQL_MappingFile
-            elif os.path.exists(os.path.join(
+                m_SQL_MappingFullName = os.path.abspath(m_SQL_MappingFile)
+            elif os.path.isfile(os.path.join(
                     os.path.dirname(m_szTestScriptFileName),
                     m_SQL_MappingFile + ".map")):
                 # 用户提供的是当前目录下的文件
                 m_SQL_MappingBaseName = os.path.basename(m_SQL_MappingFile)  # 不包含路径的文件名
                 m_SQL_MappingFullName = os.path.join(
                     os.path.dirname(m_szTestScriptFileName),
-                    m_SQL_MappingFile + ".map"
-                )
+                    m_SQL_MappingFile + ".map")
             else:
                 # 从系统目录中查找文件
                 if 'SQLCLI_HOME' in os.environ:
@@ -64,6 +68,8 @@ class SQLMapping(object):
                 continue
 
             # 加载配置文件
+            if "SQLCLI_DEBUG" in os.environ:
+                print("Loading ... [" + m_SQL_MappingFullName + "]")
             with open(m_SQL_MappingFullName, 'r') as f:
                 m_SQL_Mapping_Contents = f.readlines()
 
@@ -161,13 +167,14 @@ class SQLMapping(object):
             m_TestScriptFileName = "Console"
 
         # 检查文件名是否匹配
+        # 如果一个字符串在多个匹配规则中出现，可能被多次匹配。后一次匹配的依据是前一次匹配的结果
         m_New_SQL = p_szSQL
         for m_MappingFiles in self.m_SQL_MappingList:                           # 所有的SQL Mapping信息
             m_MappingFile_Contents = self.m_SQL_MappingList[m_MappingFiles]     # 具体的一个SQL Mapping文件
             for m_Mapping_Contents in m_MappingFile_Contents:                   # 具体的一个映射信息
                 if re.match(m_Mapping_Contents[0], m_TestScriptFileName):       # 文件名匹配
                     for (m_Key, m_Value) in m_Mapping_Contents[1]:              # 内容遍历
-                        m_New_SQL = self.ReplaceSQL(p_szSQL, m_Key, m_Value)
+                        m_New_SQL = self.ReplaceSQL(m_New_SQL, m_Key, m_Value)
         return m_New_SQL
 
 
@@ -181,13 +188,17 @@ def SQLFormatWithPrefix(p_szCommentSQLScript, p_szOutputPrefix=""):
             del m_CommentSQLLists[-1]
         else:
             break
+
     # 拼接字符串
+    bSQLPrefix = 'SQL> '
     for m_nPos in range(0, len(m_CommentSQLLists)):
         if m_nPos == 0:
-            m_FormattedString = p_szOutputPrefix + 'SQL> ' + m_CommentSQLLists[m_nPos]
+            m_FormattedString = p_szOutputPrefix + bSQLPrefix + m_CommentSQLLists[m_nPos]
         else:
             m_FormattedString = \
-                m_FormattedString + '\n' + p_szOutputPrefix + '   > ' + m_CommentSQLLists[m_nPos]
+                m_FormattedString + '\n' + p_szOutputPrefix + bSQLPrefix + m_CommentSQLLists[m_nPos]
+        if len(m_CommentSQLLists[m_nPos].strip()) != 0:
+            bSQLPrefix = '   > '
     return m_FormattedString
 
 
